@@ -753,8 +753,8 @@ cgXbaronecapabi <- function() {
     tkgrid(getFrame(xBox), sticky="nw")
     tkgrid(tklabel(top, text=gettextRcmdr("Specifications"), fg="blue"), sticky="w")
 	  tkgrid(tklabel(especFrame, text=gettextRcmdr("k = ")), sigmaEntry, sticky="w")
-	  tkgrid(tklabel(especFrame, text=gettextRcmdr("Limite Inferior:")), inferiorEntry, sticky="w")
-	  tkgrid(tklabel(especFrame, text=gettextRcmdr("Limite Superior:")), superiorEntry, sticky="w")
+	  tkgrid(tklabel(especFrame, text=gettextRcmdr("Lower Limit:")), inferiorEntry, sticky="w")
+	  tkgrid(tklabel(especFrame, text=gettextRcmdr("Upper Limit:")), superiorEntry, sticky="w")
 	  tkgrid(especFrame, sticky="w")
     tkgrid(buttonsFrame, columnspan=2, sticky="w")
     dialogSuffix(rows=4, columns=2)
